==> drools-core-7.59.0.Final-sources.jar: org/drools/core/phreak/PhreakNetworkNodeFactory.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.core.phreak;

import org.kie.api.internal.utils.ServiceRegistry;

public interface PhreakNetworkNodeFactory {

    PhreakJoinNode createPhreakJoinNode();

    PhreakEvalNode createPhreakEvalNode();

    PhreakFromNode createPhreakFromNode();

    PhreakReactiveFromNode createPhreakReactiveFromNode();

    PhreakNotNode createPhreakNotNode();

    PhreakExistsNode createPhreakExistsNode();

    PhreakAccumulateNode createPhreakAccumulateNode();

    PhreakGroupByNode createPhreakGroupByNode();

    PhreakBranchNode createPhreakBranchNode();

    PhreakQueryNode createPhreakQueryNode();

    PhreakTimerNode createPhreakTimerNode();

    PhreakAsyncSendNode createPhreakAsyncSendNode();

    PhreakAsyncReceiveNode createPhreakAsyncReceiveNode();

    PhreakRuleTerminalNode createPhreakRuleTerminalNode();

    PhreakQueryTerminalNode createPhreakQueryTerminalNode();

    class Factory {

        private static class LazyHolder {

            private static final PhreakNetworkNodeFactory INSTANCE = createInstance();

            private static PhreakNetworkNodeFactory createInstance() {
                PhreakNetworkNodeFactory factory = ServiceRegistry.getService(PhreakNetworkNodeFactory.class);
                return factory != null ? factory : new PhreakNetworkNodeFactoryImpl();
            }
        }

        public static PhreakNetworkNodeFactory get() {
            return LazyHolder.INSTANCE;
        }

        private Factory() {}
    }
}

==> drools-core-8.44.0.Final-sources.jar: org/drools/core/phreak/PhreakNetworkNodeFactory.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.core.phreak;

import org.kie.api.internal.utils.KieService;

public interface PhreakNetworkNodeFactory extends KieService {

    PhreakJoinNode createPhreakJoinNode();

    PhreakEvalNode createPhreakEvalNode();

    PhreakFromNode createPhreakFromNode();

    PhreakReactiveFromNode createPhreakReactiveFromNode();

    PhreakNotNode createPhreakNotNode();

    PhreakExistsNode createPhreakExistsNode();

    PhreakAccumulateNode createPhreakAccumulateNode();

    PhreakGroupByNode createPhreakGroupByNode();

    PhreakBranchNode createPhreakBranchNode();

    PhreakQueryNode createPhreakQueryNode();

    PhreakTimerNode createPhreakTimerNode();

    PhreakAsyncSendNode createPhreakAsyncSendNode();

    PhreakAsyncReceiveNode createPhreakAsyncReceiveNode();

    PhreakRuleTerminalNode createPhreakRuleTerminalNode();

    PhreakQueryTerminalNode createPhreakQueryTerminalNode();

    class Factory {

        private static class LazyHolder {

            private static final PhreakNetworkNodeFactory INSTANCE = createInstance();

            private static PhreakNetworkNodeFactory createInstance() {
                PhreakNetworkNodeFactory factory = KieService.load(PhreakNetworkNodeFactory.class);
                return factory != null ? factory : new PhreakNetworkNodeFactoryImpl();
            }
        }

        public static PhreakNetworkNodeFactory get() {
            return LazyHolder.INSTANCE;
        }

        private Factory() {}
    }
}
